@@ -15,11 +15,16 @@ qx.Class.define("callbackery.ui.Desktop", {
     construct : function() {
         this.base(arguments,new qx.ui.layout.VBox());
         this.set({
-            padding: [5,10,0,10]
+            padding: [5,10,0,10],
+            alignX: 'center'
         });
 
+        var width = callbackery.data.Config.getInstance().getBaseConfig().max_width;
+        if (width){
+            this.setMaxWidth(width);
+        }
         this.add(callbackery.ui.Header.getInstance());
         this.add(callbackery.ui.TabView.getInstance(),{ flex: 1})
         this.add(callbackery.ui.Footer.getInstance());
     }
-});
\ No newline at end of file
+});
